
NIFTy user guide
================

This guide is an overview and explains the main idea behind nifty. More details
are found in the `API reference <../mod/nifty8.html>`_.


.. toctree::
   :maxdepth: 1

   ift
   approximate_inference
   0_intro
   citations

In the following are guides to the old NIFTy.
They serve as reference but are likely not relevant anymore for new projects.

.. toctree::
   :maxdepth: 1

   old_nifty
   old_nifty_volume
   old_nifty_design_principles
   old_nifty_custom_nonlinearities
   old_nifty_getting_started_0
   old_nifty_getting_started_4_CorrelatedFields
